# Datamatch

[![pypi](https://img.shields.io/pypi/v/datamatch)](https://pypi.org/project/datamatch/)
[![docs](https://readthedocs.org/projects/datamatch/badge/)](https://datamatch.readthedocs.io/en/latest/)
[![release-workflow](https://github.com/pckhoi/datamatch/actions/workflows/taggedrelease.yml/badge.svg)](https://github.com/pckhoi/datamatch/actions/workflows/taggedrelease.yml)

Datamatch is a library that facilitate data matching or entity resolution. It was used in New Orleans's [LLEAD project](https://github.com/ppact/processing).

You can read the documentations [here](https://datamatch.readthedocs.io/en/latest/).

## Choosing a version

As this package is at the preproduction state, an increase in minor version-number represents breaking changes.
